#
# spec file for package python-deepdiff
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-deepdiff
Version:        6.3.0
Release:        2.3
Summary:        Deep Difference and Search of any Python object/data
License:        MIT
URL:            https://github.com/seperman/deepdiff
Source:         https://github.com/seperman/deepdiff/archive/%{version}.tar.gz#/deepdiff-%{version}-gh.tar.gz
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module jsonpickle}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module ordered-set >= 4.1.0 with %python-ordered-set < 4.2}
BuildRequires:  %{python_module orjson}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module toml}
#BuildRequires:  %%{python_module clevercsv} # not available
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       (python-ordered-set >= 4.1.0 with python-ordered-set < 4.2)
Requires(post): update-alternatives
Requires(postun):update-alternatives
Recommends:     python-PyYAML
Recommends:     python-click
Recommends:     python-jsonpickle
Recommends:     python-numpy
Recommends:     python-orjson
Recommends:     python-toml
#Suggests:     python-clevercsv
BuildArch:      noarch
%python_subpackages

%description
A Python module to calculate Deep Difference of dictionaries,
iterables, strings and other objects. It can search for objects
within other objects, and hash any object based on their content.

%prep
%autosetup -p1 -n deepdiff-%{version}
sed -i '1{/env python/d}' deepdiff/deephash.py deepdiff/diff.py deepdiff/search.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/deep
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# we don't have the (optional) requirement CleverCSV for csv diffing
donttest="(TestCommands and (csv or group_by)) or (test_load_path_content and csv)"
%pytest -k "not ($donttest)"

%post
%python_install_alternative deep

%postun
%python_uninstall_alternative deep

%files %{python_files}
%license LICENSE
%doc README.md AUTHORS.md
%{python_sitelib}/deepdiff
%{python_sitelib}/deepdiff-%{version}*-info
%python_alternative %{_bindir}/deep

%changelog
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue May  2 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 6.3.0:
  - PrefixOrSuffixOperator: This operator will skip strings that are
    suffix or prefix of each other.
  - include_obj_callback and include_obj_callback_strict are added
    by [Håvard Thom](https://github.com/havardthom).
  - Fixed a corner case where numpy's np.float32 nans are not
    ignored when using ignore_nan_equality by [Noam
    Gottlieb](https://github.com/noamgot)
  - orjson becomes optional again.
  - Fix for ignore_type_in_groups with numeric values so it does not
    report number changes when the number types are different.
* Tue May  2 2023 Daniel Garcia <daniel.garcia@suse.com>
- Move python-orjson from Recommends to Requires, it's a requirement
  right now in the latest release.
* Tue Feb 21 2023 John Vandenberg <jayvdb@gmail.com>
- Update to v6.2.3
  * Switching to Orjson for serialization to improve the performance.
  * Setting equal_nan=ignore_nan_inequality in the call for np.array_equal
  * Using Pytest's tmp_path fixture instead of /tmp/
- from 6.2.2
  * Enum test fix for python 3.11
  * Adding support for dateutils rrules
- from v6.2.1
  * Removed the print statements.
- from v6.2.0
  * Major improvement in the diff report for lists when items are all
    hashable and the order of items is important.
- from v6.1.0
  * DeepDiff.affected_paths can be used to get the list of all paths
    where a change, addition, or deletion was reported for.
  * DeepDiff.affected_root_keys can be used to get the list of all
    paths where a change, addition, or deletion was reported for.
  * Bugfix: ValueError when using Decimal 0.x
  * Serialization of UUID
- from v6.0.0
  * Exclude obj callback strict parameter is added to DeepDiff
    A fix for diffing using iterable_compare_func with nested objects
* Thu Sep  8 2022 John Vandenberg <jayvdb@gmail.com>
- Update minimum dependency ordered-set >= 4.1.0
* Fri Jun 24 2022 Benjamin Greiner <code@bnavigator.de>
- Update to 5.8.2
  * Fixing dependency for Py3.6
- DeepDiff 5.8.1 includes bug fixes:
  * Fixed test suite for 32bit systems
  * Fixed the issue when using ignore_order=True and group_by
    simultaneously
  * Added the support for diffing object properties (@property)
  * Better support of diffing private variables
- DeepDiff 5.8.0 includes bug fixes and improvements:
  * Fixed the bug with delta randomly not producing the same
    results when ignore_order=True
  * Display detailed pretty when verbose
  * Allow ordered-set version 4.1.x
  * Removing extra logging when key is not found in DeepHash
  * Fixed error when comparing non-utf8 byte strings with
    ignore_order=True
  * Fixed Tests fail after 2022-05-14
  * Fixed TypeError is thrown when comparing bool and str
* Wed Jan 26 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to 5.6.0
  * Add custom operators, and ignore_order_func.
  * Bugfix: verbose_level==0 should disable values_changes.
  * Bugfix: unprocessed key error.
  * Add iterable_compare_func for DeepDiff
  * Add output_format of list for path() in tree view
  * Add strict_checking for numbers in DeepSearch
  * Add support for regular expressions in DeepSearch
* Thu Apr  1 2021 Ben Greiner <code@bnavigator.de>
- Update to 5.2.3
  * Retaining the order of multiple dictionary items added via
    Delta.
  * Fixed the typo with yml files in deep cli.
  * Fixing Grep RecursionError where using non UTF-8 character.
  * Allowing kwargs to be passed to to_json method.
- Release 5.2.2
  * Fixed Delta serialization when None type is present.
- Release 5.2.0
  * Removed Murmur3 as the preferred hashing method. Using SHA256 by
    default now.
  * Added commandline for deepdiff.
  * Added group_by.
  * Added math_epsilon.
  * Improved ignoring of NoneType.
- Release 5.0.2
  * Bug Fix NoneType in ignore type groups
    https://github.com/seperman/deepdiff/issues/207
- Release 5.0.1
  * Bug fix to not apply format to non numbers.
- Release 5.0.0
  * Introducing the Delta object
  * Improving Numpy support
  * Fixing tuples comparison when ignore_order=True
  * Dramatically improving the results when ignore_order=True by
    running in passes
  * Introducing pretty print view, deep_distance, purge,
    progress logging, cache and truncate_datetime.
  * Adds support for datetime.time
- Skip python36 build because the test suite makes extensive use of
  NumPy.
* Thu Apr  2 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 4.3.2
  * Deprecation Warning Enhancement
  * DeepDiff not excluding paths when ignore_order is True
  * adding exclude_obj_callback
* Fri Mar  6 2020 pgajdos@suse.com
- version update to 4.2.0
  - v4-2-0: .json property is finally removed. Fix for Py3.10. Dropping support for EOL Python 3.4. Ignoring private keys when calculating hashes. For example __init__ is not a part of hash calculation anymore. Fix for #166 Problem with comparing lists, with an boolean as element.
  - v4-0-9: Fixing the bug for hashing custom unhashable objects
  - v4-0-8: Adding ignore_nan_inequality for float('nan')
  - v4-0-7: Hashing of the number 1 vs. True
  - v4-0-6: found a tiny bug in Python formatting of numbers in scientific notation. Added a workaround.
  - v4-0-5: Fixing number diffing. Adding number_format_notation and number_to_string_func.
  - v4-0-4: Adding ignore_string_case and ignore_type_subclasses
  - v4-0-3: Adding versionbump tool for release
  - v4-0-2: Fixing installation issue where rst files are missing.
  - v4-0-1: Fixing installation Tarball missing requirements.txt . DeepDiff v4+ should not show up as pip installable for Py2. Making Murmur3 installation optional.
  - v4-0-0: Ending Python 2 support, Adding more functionalities and documentation for DeepHash. Switching to Pytest for testing. Switching to Murmur3 128bit for hashing. Fixing classes which inherit from classes with slots didn't have all of their slots compared. Renaming ContentHash to DeepHash. Adding exclude by path and regex path to DeepHash. Adding ignore_type_in_groups. Adding match_string to DeepSearch. Adding Timedelta object diffing.
  - v3-5-0: Exclude regex path
* Fri Oct  4 2019 Jan Engelhardt <jengelh@inai.de>
- Use proper sentences in descriptions.
* Wed Oct  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Use correct test call
- Format with spec-cleaner
- Fix the Source url to point to real archive
* Mon Sep 30 2019 chajain <cjain@suse.com
- Fixing LICENSE and tests
* Tue Sep 24 2019 chajain <cjain@suse.com>
- Initial package
